This is the testing package by Anshuman Mishra


----TO INSTALL----

Write the command in terminal:

--------------------------------
pip install anm_addit
--------------------------------



----HOW TO USE----

Write the following code:

--------------------------------
from anm_addit import addit

x = addit(num1, num2)

print(x)
--------------------------------



This will print (num1 + num2)